@@ -25,10 +25,16 @@
  *
  *******************************************************************************/
 
- /* $Id: log-surfnet.cpp 341 2006-02-20 09:51:00Z common $ */
+/* $Id: log-surfnet.cpp 676 2006-10-25 18:19:53Z common $ */
+
+#include <sstream>
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
 #include "log-surfnet.hpp"
-#include "DatabaseConnection.hpp"
+
 
 #include "LogManager.hpp"
 #include "EventManager.hpp"
@@ -42,14 +48,41 @@
 
 #include "Config.hpp"
 
+#include "SQLHandler.hpp"
+#include "SQLResult.hpp"
+#include "SQLManager.hpp"
+
 using namespace nepenthes;
 
 #ifdef STDTAGS 
-#undef STDTAGS 
+	#undef STDTAGS 
 #endif
 #define STDTAGS l_mod | l_ev | l_hlr
 
 
+
+
+LSDetail::LSDetail(uint32_t host, int type, string data)
+{
+	
+	m_host = inet_ntoa(*(in_addr *)&host);
+	m_type = type;
+	m_data = data;
+}
+
+
+LSContext::LSContext()
+{
+	m_attackID = 0;
+	m_closed = false;
+
+	m_severity = 0;
+}
+
+
+
+
+
 /**
  * as we may need a global pointer to our Nepenthes in our modules,
  * and cant access the cores global pointer to nepenthes
@@ -75,13 +108,15 @@ LogSurfNET::LogSurfNET(Nepenthes *nepenthes)
 {
 	m_ModuleName        = "log-surfnet";
 	m_ModuleDescription = "log various malicious events to postgresql";
-	m_ModuleRevision    = "$Rev: 341 $";
+	m_ModuleRevision    = "$Rev: 676 $";
 	m_Nepenthes = nepenthes;
 
 	m_EventHandlerName = "LogSurfNETEventHandler";
 	m_EventHandlerDescription = "hook malicious events and log them to mysql";
 
 	g_Nepenthes = nepenthes;
+
+	m_RunningMode = LS_MODE_LIST;
 }
 
 
@@ -110,7 +145,7 @@ bool LogSurfNET::Init()
 
 	if ( m_Config == NULL )
 	{
-		logCrit("%s","I need a config\n");
+		logCrit("I need a config\n");
 		return false;
 	}
 
@@ -120,35 +155,76 @@ bool LogSurfNET::Init()
 	string user;
 	string pass;
 	string db;
+	string options;
+	string mode;
 	try
 	{
 		sList = *m_Config->getValStringList("log-surfnet.ports");
-		server = m_Config->getValString("log-surfnet.server");
-		user = m_Config->getValString("log-surfnet.user");
-		pass = m_Config->getValString("log-surfnet.pass");
-		db = m_Config->getValString("log-surfnet.db");
-	} catch ( ... )
+		server  = m_Config->getValString("log-surfnet.server");
+		user    = m_Config->getValString("log-surfnet.user");
+		pass    = m_Config->getValString("log-surfnet.pass");
+		db      = m_Config->getValString("log-surfnet.db");
+		options = m_Config->getValString("log-surfnet.options");
+		mode 	= m_Config->getValString("log-surfnet.mode");
+	}
+	catch ( ... )
 	{
-		logCrit("%s","Error setting needed vars, check your config\n");
+		logCrit("Error setting needed vars, check your config\n");
 		return false;
 	}
 
 	m_Ports = (uint16_t *)malloc(sizeof(uint16_t)*sList.size());
 	m_MaxPorts = sList.size();
 
-	uint32_t i = 0;
-	while (i < sList.size())
+	try
 	{
-		m_Ports[i] = (uint16_t)atoi(sList[i]);
-		i++;
+		mode 	= m_Config->getValString("log-surfnet.mode");
+		if (mode == "list")
+		{
+			m_RunningMode = LS_MODE_LIST;
+		}
+		else
+		if ( mode == "any" )
+		{
+			m_RunningMode = LS_MODE_ANY;
+		}
+
+	}
+	catch ( ... )
+	{
+		logWarn("No 'mode' value found in config, using 'any'\n");
 	}
 
 
-	m_DB = new DatabaseConnection(server.c_str(),user.c_str(),pass.c_str(),db.c_str());
-
-	if ( m_DB->Init() == false )
+	if ( m_RunningMode == LS_MODE_LIST )
 	{
-    	return false;
+		uint32_t i = 0;
+		while ( i < sList.size() )
+		{
+			m_Ports[i] = (uint16_t)atoi(sList[i]);
+			i++;
+		}
+	}
+
+	switch (m_RunningMode)
+	{
+	case nepenthes::LS_MODE_ANY:
+		logInfo("Running mode is any port\n");
+		break;
+
+	case nepenthes::LS_MODE_LIST:
+		logInfo("Running mode is port list\n");
+		break;
+
+	}
+
+	m_SQLHandler = g_Nepenthes->getSQLMgr()->createSQLHandler("postgres",server,user,pass,db,options,this);
+
+
+	if ( m_SQLHandler == NULL )
+	{
+		logCrit("Could not create sqlhandler for the postgres database connection\n");
+		return false;
 	}
 
 
@@ -191,7 +267,7 @@ uint32_t LogSurfNET::handleEvent(Event *event)
 	logPF();
 	logInfo("Event %i\n",event->getType());
 
-    Socket *socket=NULL;
+	Socket *socket=NULL;
 	Dialogue *dia=NULL;
 	ShellcodeHandler *handler=NULL;
 	uint32_t localhost=0;
@@ -199,8 +275,8 @@ uint32_t LogSurfNET::handleEvent(Event *event)
 	string url="";
 	string md5sum = "";
 
-	
-	switch(event->getType())
+
+	switch ( event->getType() )
 	{
 	case EV_SOCK_TCP_ACCEPT:
 		socket = ((SocketEvent *)event)->getSocket();
@@ -236,27 +312,34 @@ uint32_t LogSurfNET::handleEvent(Event *event)
 
 
 	default:
-		logWarn("%s","this should not happen\n");
+		logWarn("this should not happen\n");
 	}
 
 
 	bool process=false;
-	map <uint32_t, uint32_t, ltint>::iterator attackit;
+	map <uint32_t, LSContext, ltint>::iterator attackit;
 	uint32_t attackid=0;
 
-	switch(event->getType())
+	switch ( event->getType() )
 	{
 	case EV_SOCK_TCP_ACCEPT:
 		{
-			uint16_t localport = socket->getLocalPort();
-			uint16_t i=0;
-			while (i < m_MaxPorts)
+			if (m_RunningMode == LS_MODE_ANY)
 			{
-				if (m_Ports[i] == localport)
+				process = true;
+			}
+			else
+			{
+				uint16_t localport = socket->getLocalPort();
+				uint16_t i=0;
+				while ( i < m_MaxPorts )
 				{
-					process=true;
+					if ( m_Ports[i] == localport )
+					{
+						process=true;
+					}
+					i++;
 				}
-				i++;
 			}
 		}
 		break;
@@ -265,14 +348,16 @@ uint32_t LogSurfNET::handleEvent(Event *event)
 	case EV_DIALOGUE_ASSIGN_AND_DONE:
 	case EV_SHELLCODE_DONE:
 		{
-			if (m_SocketTracker.count((uintptr_t) socket) == 0)
+			if ( m_SocketTracker.count((uintptr_t) socket) == 0 )
 			{
-				process=false;
-			}else
+				logCrit("Could not find attackid for %x\n",(uintptr_t) socket);
+				 process=false;
+			}
+			else
 			{
 				process=true;
 				attackit = m_SocketTracker.find((uintptr_t) socket);
-				attackid = attackit->second;
+				attackid = attackit->second.m_attackID;
 			}
 		}
 		break;
@@ -283,13 +368,13 @@ uint32_t LogSurfNET::handleEvent(Event *event)
 		break;
 
 	default:
-		logWarn("%s","this should not happen\n");
+		logWarn("this should not happen\n");
 	}
 
 
-	if (process == true)
+	if ( process == true )
 	{
-		switch(event->getType())
+		switch ( event->getType() )
 		{
 		case EV_SOCK_TCP_ACCEPT:
 			handleTCPAccept(socket);
@@ -317,40 +402,82 @@ uint32_t LogSurfNET::handleEvent(Event *event)
 
 
 		default:
-			logWarn("%s","this should not happen\n");
+			logWarn("this should not happen\n");
 		}
-	}
+	}else
+		logInfo("not processed\n");
 
 	return 0;
 }
 
+string  itos( long i )
+{
+	std::ostringstream s;
+	s << i;
+	return s.str();
+}
+
 
 void LogSurfNET::handleTCPAccept(Socket *socket)
 {
-	logCrit("handleTCPAccept()\n"
+	logPF();
+	logSpam("handleTCPAccept()\n"
 			"\tSocket 0x%x\n",
 			(uint32_t) ((intptr_t)socket));
 
-    int32_t sensorid = m_DB->getSensorID(socket->getLocalHost());
-	int32_t attackid = m_DB->addAttack(AS_POSSIBLE_MALICIOUS_CONNECTION, socket->getRemoteHost(), socket->getRemotePort(), socket->getLocalHost(), socket->getLocalPort(),sensorid);
+	string hwa = "";
+	socket->getRemoteHWA(&hwa);
 
-	m_SocketTracker[(uintptr_t)socket] = attackid;
+	uint32_t attackerip = socket->getRemoteHost();
+	uint32_t decoyip = socket->getLocalHost();
+
+	string attackerhost = inet_ntoa(*(in_addr *)&attackerip);
+	string decoyhost = inet_ntoa(*(in_addr *)&decoyip);
+
+
+	string query;
+	query = "SELECT surfnet_attack_add('";
+	query += itos(AS_POSSIBLE_MALICIOUS_CONNECTION);
+	query += "','";
+	query += attackerhost;
+	query += "','";
+	query += itos(socket->getRemotePort());
+	query += "','";
+	query += decoyhost;
+	query += "','";
+	query += itos(socket->getLocalPort());
+	if (hwa != "")
+	{
+    	query += "','";
+		query += hwa;
+		query += "','";
+	}else
+	{
+		query += "',NULL,'";
+	}
+	query += decoyhost;
+	query += "');";
+
+	m_SQLHandler->addQuery(&query,this,socket);
+	m_SocketTracker[(uintptr_t) socket].m_attackID = 0;
 }
 
 void LogSurfNET::handleTCPclose(Socket *socket, uint32_t attackid)
 {
-	logCrit("handleTCPclose()\n"
+	logPF();
+	logSpam("handleTCPclose()\n"
 			"\tSocket 0x%x\n"
 			"\tattackID %i\n",
 			(uint32_t) ((intptr_t)socket), 
 			attackid);
 
-	m_SocketTracker.erase((uintptr_t) socket);
+	m_SocketTracker[(uintptr_t) socket].m_closed = true;
 }
 
 void LogSurfNET::handleDialogueAssignAndDone(Socket *socket, Dialogue *dia, uint32_t attackid)
 {
-	logCrit("handleDialogueAssignAndDone()\n"
+	logPF();
+	logSpam("handleDialogueAssignAndDone()\n"
 			"\tSocket 0x%x\n"
 			"\tDialogue %s\n"
 			"\tattackID %i\n",
@@ -358,18 +485,47 @@ void LogSurfNET::handleDialogueAssignAndDone(Socket *socket, Dialogue *dia, uint
 			dia->getDialogueName().c_str(), 
 			attackid);
 
-	int32_t sensorid = m_DB->getSensorID(socket->getLocalHost());
+	if ( attackid > 0 )
+	{
 
-	m_DB->addDetail(attackid, sensorid, DT_DIALOGUE_NAME, dia->getDialogueName().c_str());
-	m_DB->updateAttackSeverity(attackid,AS_DEFINITLY_MALICIOUS_CONNECTION);
+		uint32_t decoyip = socket->getLocalHost();
+		string decoyhost = inet_ntoa(*(in_addr *)&decoyip);
 
+		string query;
+		query = "SELECT surfnet_detail_add('";
+		query += itos(attackid);
+		query += "','";
+		query += decoyhost;
+		query += "','";
+		query += itos(DT_DIALOGUE_NAME);
+		query += "','";
+		query += dia->getDialogueName();
+		query += "');";
+
+		m_SQLHandler->addQuery(&query,NULL,NULL);
+
+
+		query = "SELECT surfnet_attack_update_severity('";
+		query += itos(attackid);
+		query += "','";
+		query += itos(AS_DEFINITLY_MALICIOUS_CONNECTION);
+		query += "');";
+
+		m_SQLHandler->addQuery(&query,NULL,NULL);
+	}
+	else
+	{
+		LSDetail *d = new LSDetail(socket->getLocalHost(),DT_DIALOGUE_NAME,dia->getDialogueName());
+		m_SocketTracker[(uintptr_t) socket].m_Details.push_back(d);
+		m_SocketTracker[(uintptr_t) socket].m_severity = AS_DEFINITLY_MALICIOUS_CONNECTION;
+	}
 
 }
 
 
 void LogSurfNET::handleShellcodeDone(Socket *socket, ShellcodeHandler *handler, uint32_t attackid)
 {
-	logCrit("handleShellcodeDone()\n"
+	logSpam("handleShellcodeDone()\n"
 			"\tSocket 0x%x\n"
 			"\tShellcodeHandler %s\n"
 			"\tattackID %i\n",
@@ -377,36 +533,157 @@ void LogSurfNET::handleShellcodeDone(Socket *socket, ShellcodeHandler *handler,
 			handler->getShellcodeHandlerName().c_str(), 
 			attackid);
 
-//	m_DB->addDetail(int32_t attackid, char *text);
-	int32_t sensorid = m_DB->getSensorID(socket->getLocalHost());
-	m_DB->addDetail(attackid, sensorid, DT_SHELLCODEHANDLER_NAME ,handler->getShellcodeHandlerName().c_str());
+	if ( attackid > 0 )
+	{
+		uint32_t decoyip = socket->getLocalHost();
+		string decoyhost = inet_ntoa(*(in_addr *)&decoyip);
+
+		string query;
+		query = "SELECT surfnet_detail_add('";
+		query += itos(attackid);
+		query += "','";
+		query += decoyhost;
+		query += "','";
+		query += itos(DT_SHELLCODEHANDLER_NAME);
+		query += "','";
+		query += handler->getShellcodeHandlerName();
+		query += "');";
+
+		m_SQLHandler->addQuery(&query,NULL,NULL);
+	}else
+	{
+		LSDetail *d = new LSDetail(socket->getLocalHost(),DT_SHELLCODEHANDLER_NAME,handler->getShellcodeHandlerName());
+		m_SocketTracker[(uintptr_t) socket].m_Details.push_back(d);
+	}
 }
 
 
 
 void LogSurfNET::handleDownloadOffer(uint32_t localhost, uint32_t remotehost,const char *url)
 {
-	int32_t sensorid = m_DB->getSensorID(localhost);
-	int32_t attackid = m_DB->addAttack(AS_DOWNLOAD_OFFER, remotehost, 0, localhost, 0,sensorid);
-    m_DB->addDetail(attackid, sensorid, DT_DOWNLOAD_URL, url);
+	logPF();
+	string hwa = "";
+
+	string attackerhost = inet_ntoa(*(in_addr *)&remotehost);
+	string decoyhost = inet_ntoa(*(in_addr *)&localhost);
+
+	string surl = url;
+
+	string query;
+	query = "SELECT surfnet_detail_add_offer('";
+	query += attackerhost;
+	query += "','";
+	query += decoyhost;
+	query += "','";
+	query += m_SQLHandler->escapeString(&surl);
+	query += "');";
+
+	m_SQLHandler->addQuery(&query,NULL,NULL);
+
 }
 
 void LogSurfNET::handleDownloadSuccess(uint32_t localhost, uint32_t remotehost, const char *url, const char *md5hash)
 {
-	int32_t sensorid = m_DB->getSensorID(localhost);
-	int32_t attackid = m_DB->addAttack(AS_DOWNLOAD_SUCCESS, remotehost, 0, localhost, 0,sensorid);
+	logPF();
 
-    m_DB->addDetail(attackid, sensorid, DT_DOWNLOAD_URL, url);
-	m_DB->addDetail(attackid, sensorid, DT_DOWNLOAD_HASH, md5hash);
+	string attackerhost = inet_ntoa(*(in_addr *)&remotehost);
+	string decoyhost = inet_ntoa(*(in_addr *)&localhost);
+
+	string surl = url;
+	string smd5hash = md5hash;
+
+	string query;
+	query = "SELECT surfnet_detail_add_download('";
+	query += attackerhost;
+	query += "','";
+	query += decoyhost;
+	query += "','";
+	query += m_SQLHandler->escapeString(&surl);
+	query += "','";
+	query += m_SQLHandler->escapeString(&smd5hash);
+	query += "');";
+
+	m_SQLHandler->addQuery(&query,NULL,NULL);
+}
+
+
+bool LogSurfNET::sqlSuccess(SQLResult *result)
+{
+	logPF();
+	Socket *s;
+	vector< map<string,string> > resvec = *result->getResult();
+	s = (Socket *)result->getObject();
+
+	logCrit("Socket %x  has cookie %s \n",(uintptr_t)s,
+			resvec[0]["surfnet_attack_add"].c_str());
+	m_SocketTracker[(uintptr_t)s].m_attackID = atoi(resvec[0]["surfnet_attack_add"].c_str());
+
+
+	if (m_SocketTracker[(uintptr_t)s].m_Details.size() > 0)
+	{
+		logDebug("Processing Event Backlog for this connection\n");
+	}
+
+	while (m_SocketTracker[(uintptr_t)s].m_Details.size() > 0)
+	{
+/*		logSpam("WOOOOHOOOOO %s %s %i \n",
+				m_SocketTracker[(uintptr_t)s].m_Details.front()->m_host.c_str(),
+				m_SocketTracker[(uintptr_t)s].m_Details.front()->m_data.c_str(),
+				m_SocketTracker[(uintptr_t)s].m_Details.front()->m_type);
+*/
+
+		string query;
+		query = "SELECT surfnet_detail_add('";
+		query += itos(m_SocketTracker[(uintptr_t)s].m_attackID);
+		query += "','";
+		query += m_SocketTracker[(uintptr_t)s].m_Details.front()->m_host;
+		query += "','";
+		query += itos(m_SocketTracker[(uintptr_t)s].m_Details.front()->m_type);
+		query += "','";
+		query += m_SocketTracker[(uintptr_t)s].m_Details.front()->m_data.c_str();
+		query += "');";
+
+		m_SQLHandler->addQuery(&query,NULL,NULL);
+
+		delete m_SocketTracker[(uintptr_t)s].m_Details.front();
+		m_SocketTracker[(uintptr_t)s].m_Details.pop_front();
+	}
+
+	if (m_SocketTracker[(uintptr_t)s].m_closed == true)
+	{
+		m_SocketTracker.erase((uintptr_t)s);
+	}
+
+	return true;
+}
+
+bool LogSurfNET::sqlFailure(SQLResult *result)
+{
+	logPF();
+	return true;
+}
+
+void LogSurfNET::sqlConnected()
+{
+	logPF();
+}
+
+void LogSurfNET::sqlDisconnected()
+{
+	logPF();
 }
 
 
 extern "C" int32_t module_init(int32_t version, Module **module, Nepenthes *nepenthes)
 {
-	if (version == MODULE_IFACE_VERSION) {
-        *module = new LogSurfNET(nepenthes);
-        return 1;
-    } else {
-        return 0;
-    }
+	if ( version == MODULE_IFACE_VERSION )
+	{
+		*module = new LogSurfNET(nepenthes);
+		return 1;
+	}
+	else
+	{
+		return 0;
+	}
 }
+
