@@ -26,7 +26,7 @@
  *******************************************************************************/
 
 
-/* $Id: sch_generic_cmd.cpp 341 2006-02-20 09:51:00Z common $ */
+/* $Id: sch_generic_cmd.cpp 550 2006-05-04 10:25:35Z common $ */
 
 
 
@@ -105,7 +105,7 @@ sch_result GenericCMD::handleShellcode(Message **msg)
 
         if (g_Nepenthes->getFactoryMgr()->getFactory("WinNTShell DialogueFactory") == NULL)
 		{
-			logCrit("%s","No WinNTShell DialogueFactory availible \n");
+			logCrit("No WinNTShell DialogueFactory availible \n");
 			return SCH_DONE;
 		}
 
