@@ -36,7 +36,7 @@
  *
  */
 
-/* $Id: sch_generic_createprocess.cpp 341 2006-02-20 09:51:00Z common $ */
+/* $Id: sch_generic_createprocess.cpp 550 2006-05-04 10:25:35Z common $ */
 
 
 
@@ -127,7 +127,7 @@ sch_result GenericCreateProcess::handleShellcode(Message **msg)
 		
 		if (g_Nepenthes->getFactoryMgr()->getFactory("WinNTShell DialogueFactory") == NULL)
 		{
-			logCrit("%s","No WinNTShell DialogueFactory availible \n");
+			logCrit("No WinNTShell DialogueFactory availible \n");
 			return SCH_DONE;
 		}
 
