@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
- /* $Id: submit-file.cpp 332 2006-02-20 09:28:45Z common $ */
+ /* $Id: submit-file.cpp 550 2006-05-04 10:25:35Z common $ */
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -53,7 +53,7 @@ FileSubmitHandler::FileSubmitHandler(Nepenthes *nepenthes)
 {
 	m_ModuleName        = "submit-file";
 	m_ModuleDescription = "module providing a file to file submitter";
-	m_ModuleRevision    = "$Rev: 332 $";
+	m_ModuleRevision    = "$Rev: 550 $";
 	m_Nepenthes = nepenthes;
 
 	m_SubmitterName = "submit-file";
@@ -73,7 +73,7 @@ bool FileSubmitHandler::Init()
 
 	if ( m_Config == NULL )
 	{
-		logCrit("%s","I need a config\n");
+		logCrit("I need a config\n");
 		return false;
 	}
 
@@ -82,7 +82,7 @@ bool FileSubmitHandler::Init()
 		m_FilePath = m_Config->getValString("submit-file.path");
     } catch ( ... )
 	{
-		logCrit("%s","Error setting needed vars, check your config\n");
+		logCrit("Error setting needed vars, check your config\n");
 		return false;
 	}
 
