@@ -25,12 +25,13 @@
  *
  *******************************************************************************/
 
-/* $Id: LogHandler.hpp 321 2006-02-20 08:30:38Z common $ */
+/* $Id: LogHandler.hpp 664 2006-10-11 18:25:03Z dp $ */
 
 #ifndef LOGHANDLER_HPP
 #define LOGHANDLER_HPP
 
 #include <stdint.h>
+#include <sys/types.h>
 
 namespace nepenthes
 {
@@ -45,7 +46,8 @@ namespace nepenthes
 //						LogHandler(LogManager *lm);
 		virtual			~LogHandler();
 		virtual void	log(uint32_t mask, const char *message) = 0;
-	
+		virtual bool	setOwnership(uid_t uid, gid_t gid) = 0;
+
 	protected:
 		LogManager		*m_LogManager;
 	};
