@@ -25,7 +25,7 @@
  *
  *******************************************************************************/
 
-/* $Id: DownloadManager.cpp 2096 2005-10-23 18:59:41Z common $ */
+/* $Id: DownloadManager.cpp 505 2006-04-09 16:39:36Z oxff $ */
 
 #include <string>
 
@@ -114,15 +114,15 @@ bool  DownloadManager::Exit()
  * these cool makros are taken from the clamav mailing list  
  * 
  */
-#ifndef BIG_ENDIAN
-	#define SWAP_ORDER(x) (x)
-#else
+//#ifndef BIG_ENDIAN
+//	#define SWAP_ORDER(x) (x)
+//#else
 	#define SWAP_ORDER(x) ( \
 		((x & 0xff) << 24) | \
 		((x & 0xff00) << 8) | \
 		((x & 0xff0000) >> 8 ) | \
 		((x & 0xff000000) >> 24 ))
-#endif
+//#endif
 
 #define PACKADDR(a, b, c, d) SWAP_ORDER((((uint32_t)(a) << 24) | ((b) << 16) | ((c) << 8) | (d)))
 #define MAKEMASK(bits)	SWAP_ORDER(((uint32_t)(0xffffffff << (32-bits))))
@@ -248,22 +248,22 @@ ip_range_t DownloadManager::m_irLocalRanges[] =
 void DownloadManager::doList()
 {
 	list <DownloadHandlerTuple>::iterator dhandler;
-	logInfo("=--- %-69s ---=\n","DownloadManager");
+	logSpam("=--- %-69s ---=\n","DownloadManager");
 	uint32_t i=0;
 	for(dhandler = m_DownloadHandlers.begin();dhandler != m_DownloadHandlers.end();dhandler++,i++)
 	{
-		logInfo("  %i) %5s %-8s %s\n",i,dhandler->m_Protocol.c_str() ,dhandler->m_Handler->getDownloadHandlerName().c_str(), dhandler->m_Handler->getDownloadHandlerDescription().c_str());
+		logSpam("  %i) %5s %-8s %s\n",i,dhandler->m_Protocol.c_str() ,dhandler->m_Handler->getDownloadHandlerName().c_str(), dhandler->m_Handler->getDownloadHandlerDescription().c_str());
 	}
-    logInfo("=--- %2i %-66s ---=\n",i, "DownloadHandlers registerd");
+	logSpam("=--- %2i %-66s ---=\n",i, "DownloadHandlers registerd");
 
 	for ( i = 0; i < sizeof(m_irLocalRanges) / sizeof(ip_range_t); i++ )
 	{
 		string range= inet_ntoa(*(in_addr *)&m_irLocalRanges[i].m_ulAddress);
 		range += "/";
 		range += inet_ntoa(*(in_addr *)&m_irLocalRanges[i].m_ulMask);
-		logInfo("Ignoring %s \n", range.c_str());
+		logSpam("Ignoring %s \n", range.c_str());
 	}
-	logInfo("=--- %2i %-66s ---=\n\n",i, "Ranges ignored");
+	logSpam("=--- %2i %-66s ---=\n\n",i, "Ranges ignored");
 
 }
 
